# eric7.QScintilla.EditorOutlineSizesDialog

Module implementing a dialog to change the default size settings of the Source Outline pane.

### Global Attributes

None

### Classes

EditorOutlineSizesDialog | Class implementing a dialog to change the default size settings of the Source Outline pane.

### Functions

None

## EditorOutlineSizesDialog

Class implementing a dialog to change the default size settings of the Source Outline pane.

### Derived from

QDialog, Ui_EditorOutlineSizesDialog

### Class Attributes

None

### Class Methods

None

### Methods

EditorOutlineSizesDialog | Constructor
getSizes | Public method to retrieve the entered values.
on_buttonBox_clicked | Private slot to handle the selection of a dialog button.

### Static Methods

None

#### EditorOutlineSizesDialog (Constructor)

EditorOutlineSizesDialog(currentWidth, defaultWidth, parent=None)

Constructor

currentWidth (int)
  value of the current width
defaultWidth (int)
  value of the default width
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### EditorOutlineSizesDialog.getSizes

getSizes()

Public method to retrieve the entered values.

Return:
  new default width value

Return Type:
  int

#### EditorOutlineSizesDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot to handle the selection of a dialog button.

button (QAbstractButton)
  reference to the clicked button

Up